{% load simple_translation_tags %}

{% comment %}previously we used the get_name filter for the person. Now the unicode method of the person defaults to that output.{% endcomment %}
{{ person }}

{% endwith %}
